@@ -12,13 +12,15 @@ getEuropeReferenceTable <- function(){
 #' @rdname spMaps
 #' 
 #' @export
-#' 
-#' @import rgeos
-#' @importFrom raster aggregate
+#'
+#' @importFrom sf st_cast
+#' @importFrom methods as
 getEuropeCountries <- function(mergeCountry = TRUE){
   europe_countries_10m
   if(mergeCountry){
-    europe_countries <- raster::aggregate(europe_countries_10m, by = c("code", "admin"))
+    europe_sf <- sf::st_as_sf(europe_countries_10m)
+    aggregated_sf <- sf::st_cast(europe_sf, "MULTIPOLYGON", group = c("code", "admin"))
+    europe_countries <- as(aggregated_sf, "Spatial")
     europe_countries$name <- europe_countries$admin
     return(europe_countries)
   } else {
